Receiver

Struct Receiver 

pub struct Receiver<T, const N: usize> { /* private fields */ }
The receiving half of a channel.

Receivers can be cloned to allow multiple consumers.

Implementations

Source

impl<T, const N: usize> Receiver<T, N>

pub fn recv(&self) -> Result<T>

Receives a value from the channel.

Errors

Returns Err(QueueEmpty) if no values are available.

pub fn try_recv(&self) -> Result<T>

Attempts to receive a value without blocking.

Alias for recv.

Errors

Returns Err(QueueEmpty) if no values are available.

pub fn recv_spin(&self) -> T

Receives a value, spinning until one is available.

pub fn is_empty(&self) -> bool

Returns true if the channel is empty.

pub fn len(&self) -> usize

Returns the number of values in the channel.

pub fn capacity(&self) -> usize

Returns the capacity of the channel.

pub fn recv_batch(&self, buf: &mut [T], max: usize) -> usize

pub fn recv_timeout(&self, timeout: Duration) -> Result<T>

Receives a value with a timeout.

Spins until a value is available or timeout is reached.

Errors

Returns Err(QueueEmpty) if timeout is reached before a value is available.