pub struct Receiver<T, const N: usize> { /* private fields */ }Expand description
The receiving half of a channel.
Receivers can be cloned to allow multiple consumers.
Implementations
Sourceimpl<T, const N: usize> Receiver<T, N>
impl<T, const N: usize> Receiver<T, N>
pub fn recv_batch(&self, buf: &mut [T], max: usize) -> usize
Sourcepub fn recv_timeout(&self, timeout: Duration) -> Result<T>
pub fn recv_timeout(&self, timeout: Duration) -> Result<T>
Receives a value with a timeout.
Spins until a value is available or timeout is reached.
Errors
Returns Err(QueueEmpty) if timeout is reached before a value is available.